/*
 * COPYRIGHT 2020-2021 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 * The contents of this file are proprietary and confidential.
 * Unauthorised copying of this file, via any medium is strictly prohibited.
 */

#import <Foundation/Foundation.h>
#import <YOAdManagement/YOCreative.h>

@class YOVASTProperty;
@class YOResource;

/**
 * @brief Represents a non-linear creative object.
 *
 * Encapsulates the data from the `<NonLinear>` element of a VAST document.\n
 * It is usually a graphic that overlays a small portion of the advert's video and is normally clickable.
 *
 * @note The class implements YOCreativeEventHandling so that it can raise `NonLinearClickTracking` and
 * analytic events on behalf of a client. It supports the following event strings:
 * - `acceptInvitation` and `overlayViewDuration`
 * .
 * If the creative is a child of a nonlinear advert then it supports the following event strings:
 * - `mute` and `unmute`
 * - `pause` and `resume`
 * - `rewind` and `skip`
 * - `playerExpand`, `playerCollapse`, `adExpand`, `adCollapse` and `minimize`
 * - `creativeView`, `acceptInvitation` and `close`
 * - `overlayViewDuration`
 * .
 */
@interface YONonLinearCreative : YOCreative <YOCreativeEventHandling>

/** Defines whether the non-linear creative is active and is to be displayed. Tracking events are fired only for creatives that are visible. */
@property (nonatomic, getter=isVisible) BOOL visible;

/**
 * Returns the properties for the non-linear creative. The properties are represented as YOVASTProperty objects. Possible properties are:
 * - width
 * - height
 * - expandedWidth
 * - expandedHeight
 * - minimumSuggestedDuration
 * - scalable
 * - maintainAspect
 * - apiFramework
 * .
 * @return An array of objects that represent the properties of the non-linear creative.
 * @see YOVASTProperty
 */
- (nonnull NSArray*) properties;

/**
 * Returns a named property for the non-linear creative if it exists. Possible properties are:
 * - width
 * - height
 * - expandedWidth
 * - expandedHeight
 * - minimumSuggestedDuration
 * - scalable
 * - maintainAspect
 * - apiFramework
 * .
 *
 * @param name The property name.
 * @return The requested property or `nil` if it does not exist.
 * @see YOVASTProperty
 */
- (nullable YOVASTProperty*) property:(nonnull NSString*)name;

/**
 * Returns the resources for the non-linear creative. Each dictionary entry contains an array of resources (YOResource) keyed on the resource type (YOResourceType).\n
 * The resource type key is packaged in an NSNumber object, for example: `[NSNumber numberWithInt:YOStaticResource]`.\n
 * The three resource types are optional elements; the dictionary will contain between one and three entries.
 *
 * @return a dictionary containing resources for the non-linear creative, keyed on the resource type.
 */
- (nonnull NSDictionary*) resources;

/**
 * Returns the resource of the requested type or `nil` if the non-linear creative does not have that resource type.
 *
 * @param type The resource type.
 * @return A resource of the requested type, or `nil`.
 * @see YOResourceType
 * @see YOResource
 */
- (nullable YOResource*) resourceOfType:(YOResourceType) type;

@end
