/*
 * COPYRIGHT 2020 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 * The contents of this file are proprietary and confidential.
 * Unauthorised copying of this file, via any medium is strictly prohibited.
 */

#import <Foundation/Foundation.h>
#import <YOAdManagement/YOCreativeEventHandling.h>

@class YOTrackingReport;
@class YOVASTProperty;

/**
 * @brief Represents an interactive unit object.
 *
 * Encapsulates the data from the `<InteractiveCreativeFile>` element of a VAST document.\n
 * It is used to provide a more interactive experience using additional creative functionality by making
 * use of a vendor's interactive APIs.
 *
 * @note The class implements YOCreativeEventHandling so that it can raise analytic events on behalf
 * of a client. It supports the following event strings:
 * - `mute` and `unmute`
 * - `pause` and `resume`
 * - `rewind` and `skip`
 * - `playerExpand` and `playerCollapse`
 * - `Impression` and `closeLinear`
 * - `customClick`
 * .
 */
@interface YOInteractiveUnit : NSObject <YOCreativeEventHandling>

/** Defines the source URL of the interactive unit. */
@property (nonnull, readonly) NSString* source;

/** Defines the duration of the interactive unit, in seconds. */
@property (nonatomic, readonly) NSTimeInterval duration;

/** Defines whether the interactive unit is active and is to be displayed. Tracking events are available only for interactive units that are visible.\n
 A client MUST call this method prior to displaying the interactive unit and again when the interactive unit is closed. */
@property (nonatomic, getter=isVisible) BOOL visible;

/**
 * Defines the ad parameters of the interactive unit.
 *
 * @see YOVASTProperty
 */
@property (nullable, readonly) YOVASTProperty* adParameters;

/**
 * Returns the properties for the interactive unit. The properties are represented as YOVASTProperty objects. Possible properties are:
 * - type
 * - apiFramework
 * - variableDuration
 * .
 * @return An array of objects that represent the properties of the interactive unit.
 * @see YOVASTProperty
 */
- (nonnull NSArray*) properties;

/**
 * Returns a named property for the interactive unit if it exists. Possible properties are
 * - type
 * - apiFramework
 * - variableDuration
 * .
 *
 * @param name The property name.
 * @return The requested roperty or `nil` if it does not exist.
 * @see YOVASTProperty
 */
- (nullable YOVASTProperty*) property:(nonnull NSString*)name;

@end
