/*
 * COPYRIGHT 2020-2021 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 * The contents of this file are proprietary and confidential.
 * Unauthorised copying of this file, via any medium is strictly prohibited.
 */

#import <Foundation/Foundation.h>
#import <YOAdManagement/YOAdManagementTypes.h>

/**
 * Provides a means for a client to specify custom properties at session initialisation.
 */
@interface YOSessionProperties : NSObject <NSCopying>

/**
 * Defines the receiver's timeout interval, in seconds, for HTTP requests for session initialisation and CSM polling.\n
 * If during a connection attempt the request remains idle for longer than this value, the request is considered to have timed out.
 *
 * @note The default value is 5 seconds.
 * */
@property NSTimeInterval timeout;

/**
 * Defines whether to keep the proxy component alive after the master manifest is read. The default behaviour is to shutdown the proxy.\n
 * This property is relevant only for Live and DVR Live playback.
 *
 * @note The default value is `NO`.
 */
@property BOOL keepProxyAlive;

/**
 * Defines the HTTP user-agent to be used by the Yospace Session when firing remote analytics tracking events.
 *
 * @note The default value is `nil` in which case the SDK will use the system-defined user agent.
 */
@property (nonnull, copy) NSString* userAgent;

/**
 * Defines the HTTP user-agent to be used by the Yospace Session when fetching the manifest during Proxied Initialisation for Live or DVR Live playback.
 *
 * @note The default value is `nil` in which case the SDK will use the system-defined user agent.
 */
@property (nonnull, copy) NSString* proxyUserAgent;

/**
 * Describes whether to prefetch non-linear resources defined in the VAST for this advert. Prefetching resources allows the application to use or
 * display the resource as soon as the advert starts without the application having to fetch it first. If the fetch is successful then the resource
 * is available from the resource property of the NonLinearCreative associated with the advert.
 *
 * @note The default value is `NO`
 */
@property BOOL prefetchNonlinearResources;

/**
 * Describes whether the SDK should fire time-based Beacons for adverts that have finished playing out. The SDK will only do this if it receives
 * Beacon data for the historical advert while still playing back the ad break in which that advert was defined.
 *
 * @note The default value is `YES`.
 */
@property BOOL fireHistoricalBeacons;

/**
 * Defines the categories of analytic tracking Beacons to exclude from analytic suppression.
 * By default, no categories are set.
 *
 * @see YOSession#suppressAnalytics:
 */
@property YOEventCategories excludeFromSuppression;

/**
 * Defines a set of debug flags that control aspects of logging output.
 *
 * @param value OR'ed combination of debug flags.
 * @note New values must by OR'ed together e.g. `[YOSessionProperties setDebugFlags:DEBUG_PARSING | DEBUG_VAST_POLLING];`
 * @note By default no flags are set.
 * @see YODebugFlags
 */
+ (void) setDebugFlags:(YODebugFlags)value;

/**
 * Defines a set of debug flags, in addition to the default set, that control aspects of logging output.
 *
 * @param value OR'ed combination of debug flags
 * @note New values must by OR'ed together e.g. `[YOSessionProperties addDebugFlags:DEBUG_PARSING | DEBUG_VAST_POLLING];`
 * @note By default no flags are set.
 * @see YODebugFlags
 */
+ (void) addDebugFlags:(YODebugFlags)value;

@end
