/*
 * COPYRIGHT 2020 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 * The contents of this file are proprietary and confidential.
 * Unauthorised copying of this file, via any medium is strictly prohibited.
 */

#ifndef YOAnalyticEvents_h
#define YOAnalyticEvents_h

/*! \defgroup notif_defs Analytic Notifications
 *  This section lists the analytic notification names that clients can observe to receive analytic events.
 *  Analytic events are broadcast through the default notification center.
 *
 *  Also listed are dictionary keys for those notifications that provide additional data through the user info property
 *  of the notification.

 *  Clients should subscribe to events that they are interested in, for example:
 *  @code
 *  [[NSNotificationCenter defaultCenter] addObserver:self
 *                                           selector:@selector(adBreakDidStart:)
 *                                               name:YOAdvertBreakStartNotification
 *                                             object:nil];
 * @endcode
 */

/** \ingroup notif_defs
 *
 * Posted when an advert break begins. The notification contains a single dictionary entry keyed on \ref YOAdBreakKey
 * that is the YOAdBreak object. For linear playback it is possible  that the ad break is not known (i.e. that analytic data
 * has not yet been provided for the ad break), in this case the dictionary is empty. */
extern NSString* const YOAdvertBreakStartNotification;

/** \ingroup notif_defs
 
 Posted when an advert break ends.
 */
extern NSString* const YOAdvertBreakEndNotification;

/** \ingroup notif_defs
 *
 * Posted when an advert begins. The notification contains a single dictionary entry keyed on \ref YOAdvertKey that is the YOAdvert object.
 *
 * For linear playback only, the notification may be posted after playback of an advert actually begins - if advert data is received late
 * from the Yospace Central Streaming Manager. In this case a client should check the advert start position against the playhead position
 * when the notification was received to determine how late the signal is.
 */
extern NSString* const YOAdvertStartNotification;

/** \ingroup notif_defs
 *
 * Posted when an advert ends.
 */
extern NSString* const YOAdvertEndNotification;

/** \ingroup notif_defs
 *
 * Posted when an analytic payload is received from the Yospace Central Streaming Manager. For live playback this
 * indicates that an advert break is upcoming, for non-linear playback this indicates that a change to the timeline has occurred
 * and the client should fetch the updated data from the non-linear Session. For any playback mode it may indicate also that one
 * or more non-linear ad breaks are available to be used.
 *
 * @see YOSessionVOD
 */
extern NSString* const YOAnalyticUpdateNotification;

/** \ingroup notif_defs
 *
 * Posted when an analytic tracking event occurs. The notification contains a single dictionary entry:
 * - \ref YOEventNameKey - an `NSString` that is the name of the event, which may be taken from either the event attribute of the `<Tracking>` element
 *   e.g. `creativeView` or the event element name e.g. `IconViewTracking`.
 * .
 *
 * Possible events are:
 * - time-based tracking event e.g. `midpoint`
 * - action-based tracking event e.g. `mute`
 * - `ClickTracking`, `NonLinearClickTracking`, `CompanionClickTracking`, `IconClickTracking`, `IconViewTracking`
 * .
 */
extern NSString* const YOTrackingEventNotification;

// dictionary keys

/** \ingroup notif_defs
 *
 * The ad break dictionary key for the \ref YOAdvertBreakStartNotification notification.
 */
extern NSString* const YOAdBreakKey;

/** \ingroup notif_defs
 *
 * The advert dictionary key for the \ref YOAdvertStartNotification notification.
 */
extern NSString* const YOAdvertKey;

/** \ingroup notif_defs
 *
 * The event name dictionary key for the \ref YOTrackingEventNotification notification.
 */
extern NSString* const YOEventNameKey;

#endif /* YOAnalyticEvents_h */
